paulicirc.circuits
==================

.. automodule:: paulicirc.circuits

Circuit
-------

.. autoclass:: paulicirc.circuits.Circuit
    :show-inheritance:
    :members:
    :special-members: __bytes__, __new__, __getitem__, __setitem__

CircuitData
-----------

.. autodata:: paulicirc.circuits.CircuitData

CircuitListing
--------------

.. autoclass:: paulicirc.circuits.CircuitListing
    :show-inheritance:
    :members:
    :special-members: __new__, __repr__

CommutationCodeArray
--------------------

.. autodata:: paulicirc.circuits.CommutationCodeArray

PHASE_NBYTES
------------

.. autodata:: paulicirc.circuits.PHASE_NBYTES

TYPE_CHECKING
-------------

.. autodata:: paulicirc.circuits.TYPE_CHECKING

commute_circuit
---------------

.. autofunction:: paulicirc.circuits.commute_circuit

get_circuit_legs
----------------

.. autodata:: paulicirc.circuits.get_circuit_legs

rand_circ
---------

.. autofunction:: paulicirc.circuits.rand_circ

set_circuit_legs
----------------

.. autofunction:: paulicirc.circuits.set_circuit_legs

statevec_from_gadgets
---------------------

.. autofunction:: paulicirc.circuits.statevec_from_gadgets

transversal_set_gadget_leg_at
-----------------------------

.. autodata:: paulicirc.circuits.transversal_set_gadget_leg_at

transversal_set_phase
---------------------

.. autodata:: paulicirc.circuits.transversal_set_phase

unitary_from_gadgets
--------------------

.. autofunction:: paulicirc.circuits.unitary_from_gadgets

zero_circ
---------

.. autofunction:: paulicirc.circuits.zero_circ
